// minimal vertex shader
// www.lighthouse3d.com

void main()
{	
  vec3 normal, lightDir;
  vec4 diffuse, specular;
  float NdotL, NdotHV;

  // transform surface normal to eye space and make unit
  normal = normalize(gl_NormalMatrix * gl_Normal);

  // not make light direction unit (light position is stored in eye space)
  lightDir = normalize(vec3(gl_LightSource[0].position));

  // compute cosine of angle between surface normal and light direction
  NdotL = max(dot(normal, lightDir), 0.0);

  // compute diffuse term

  diffuse = gl_FrontMaterial.diffuse * gl_LightSource[0].diffuse;

  // compute specular term

  if (NdotL > 0.0) {

    NdotHV = max(dot(normal, normalize(gl_LightSource[0].halfVector.xyz)),0.0);
    //    specular = gl_FrontMaterial.specular * gl_LightSource[0].specular * pow(NdotHV,gl_FrontMaterial.shininess);
    specular = pow(NdotHV,64.0)*vec4(1.0, 0.0, 0.0, 1.0);
  } 
  else
    specular = vec4(0.0, 0.0, 0.0, 1.0);

  gl_FrontColor =  NdotL * diffuse + specular;
  
  gl_Position = ftransform();

}
